
#Hello User

This is a simple example project demonstrating how to publish a python module to PyPI

## Installation

Run the following to install:

pip install HelloUser542

##Usage

```python

from HelloUser542 import sayHello

#Generate "Hello, User!"
sayHello()

#Generate "Hello, EveryOne!"
sayHello("EveryOne")
```